@@ -23,6 +23,10 @@ def post_crude_price_set(price_set, region_id: str):
     set_url = f"{api_url}/{region_id}"
     payload = json.dumps(price_set)
     d = hcometcore.generic_api_call(
-        set_url, payload=payload, requestType="POST", response_code=201, convert="true"
+        set_url,
+        payload=payload,
+        requestType="POST",
+        expected_response_code=201,
+        convert="true",
     )
     return d
